"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DataSourceManager_1 = require("../../src/data_source/base/DataSourceManager");
const restify_errors_1 = require("restify-errors");
const UUID = require("uuid");
const LoggerHelper_1 = require("../../src/helper/logger/LoggerHelper");
const MemoryDataSource_1 = require("../../src/data_source/MemoryDataSource");
const ElasticSearchDatasource_1 = require("../../src/data_source/elastic/ElasticSearchDatasource");
/**
 * Class that abstract access of database for article services.
 */
class ItemController {
    createItem(item) {
        return new Promise(function (resolve, reject) {
            // If itemId is undefined or hasn't UUID format, generate UUID for resource.
            if (!item.itemId) {
                item.itemId = UUID.v4();
            }
            else if (!item.itemId.match(/^[a-z]+-[0-9]+$/i)) {
                reject(new restify_errors_1.UnprocessableEntityError("Property itemId doesn't match expected pattern: the only" +
                    " allowed format for creation is XYZ-1234"));
            }
            LoggerHelper_1.LoggerHelper.getDefaultHandler().info("CREATE: " + item.itemId);
            ItemController.dataManager.putData(item.itemId, item).then((data) => {
                resolve(data);
            }).catch((err) => {
                reject(err);
            });
        });
    }
    updateItem(item) {
        return new Promise(function (resolve, reject) {
            ItemController.dataManager.updateData(item.itemId, item).then((data) => {
                resolve(data);
            }).catch((err) => {
                reject(err);
            });
        });
    }
    getItem(key, fields) {
        return new Promise(function (resolve, reject) {
            ItemController.dataManager.getData(key, fields).then((data) => {
                resolve(data);
            }).catch((err) => {
                reject(err);
            });
        });
    }
    search(query) {
        return new Promise(function (resolve, reject) {
            ItemController.dataManager.searchData(query).then((data) => {
                resolve(data);
            }).catch((err) => {
                reject(err);
            });
        });
    }
    getItemCollection(items, fields) {
        return new Promise(function (resolve, reject) {
            ItemController.dataManager.getItems(items, fields).then((data) => {
                resolve(data);
            }).catch((err) => {
                reject(new restify_errors_1.NotAcceptableError("Some of the articles don't exists!", err));
            });
        });
    }
}
ItemController.dataManager = new DataSourceManager_1.DataSourceManager(new MemoryDataSource_1.MemoryDataSource(), new ElasticSearchDatasource_1.ElasticSearchDataSource());
exports.ItemController = ItemController;
//# sourceMappingURL=ItemController.js.map