"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const LogHandler_1 = require("./LogHandler");
const ServerLogger_1 = require("./ServerLogger");
class LogBuilder {
    constructor() {
        this.loggers = [];
        this.level = "info";
    }
    withLogger(logger) {
        this.loggers.push(logger);
        return this;
    }
    withLevel(level) {
        this.level = level;
        return this;
    }
    build() {
        // default logger
        this.withLogger(new ServerLogger_1.default);
        // apply log level
        this.loggers.forEach((logger) => {
            logger.setLevel(this.level);
        });
        return new LogHandler_1.default(this.loggers);
    }
}
exports.LogBuilder = LogBuilder;
exports.default = LogBuilder;
//# sourceMappingURL=LogBuilder.js.map