"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const restify_errors_1 = require("restify-errors");
const Joi = require("joi");
var RestifyValidation;
(function (RestifyValidation) {
    /**
     * @param field
     * @returns {(target:Object, key:string, descriptor:TypedPropertyDescriptor<any>)=>TypedPropertyDescriptor<any>}
     */
    function isAlphanumeric(field) {
        return Validator.paramValidation((params) => {
            return params[field].match(/^[a-z0-9\-_]+$/i) !== null;
        }, new restify_errors_1.NotAcceptableError("The " + field + " must be alphanumeric"));
    }
    RestifyValidation.isAlphanumeric = isAlphanumeric;
    function isNumeric(field) {
        return Validator.paramValidation((params) => {
            return params[field].match(/^\d+$/) !== null;
        }, new restify_errors_1.NotAcceptableError("The " + field + " must be numeric"));
    }
    RestifyValidation.isNumeric = isNumeric;
    /**
     * @param bodySchema
     * @returns {(target:Object, key:string, descriptor:TypedPropertyDescriptor<any>)=>TypedPropertyDescriptor<any>}
     */
    function validateBodyWithSchema(bodySchema) {
        return function (target, key, descriptor) {
            if (descriptor === undefined) {
                descriptor = Object.getOwnPropertyDescriptor(target, key);
            }
            let originalMethod = descriptor.value;
            descriptor.value = function (req, res, next) {
                if (req.params === false) {
                    res.send(new restify_errors_1.NotAcceptableError("Body params can't be undefined"));
                }
                else {
                    Joi.validate(req.params, bodySchema, function (err, value) {
                        if (!!err) {
                            res.send(new restify_errors_1.UnprocessableEntityError(err.details[0].message));
                        }
                        else {
                            let args = [req, res, next];
                            originalMethod.apply(this, args);
                        }
                    });
                }
            };
            return descriptor;
        };
    }
    RestifyValidation.validateBodyWithSchema = validateBodyWithSchema;
    class Validator {
        /**
         * @param validation
         * @param message
         * @returns {(target:Object, key:string, descriptor:TypedPropertyDescriptor<any>)=>TypedPropertyDescriptor<any>}
         */
        static paramValidation(validation, message) {
            return function (target, key, descriptor) {
                if (descriptor === undefined) {
                    descriptor = Object.getOwnPropertyDescriptor(target, key);
                }
                let originalMethod = descriptor.value;
                descriptor.value = function (req, res, next) {
                    if (validation(req.params) === false) {
                        res.send(message);
                    }
                    else {
                        let args = [req, res, next];
                        originalMethod.apply(this, args);
                    }
                };
                return descriptor;
            };
        }
    }
    RestifyValidation.Validator = Validator;
})(RestifyValidation = exports.RestifyValidation || (exports.RestifyValidation = {}));
//# sourceMappingURL=validation.js.map