"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class RouterConfig {
    constructor(version) {
        this._routers = [];
        this._version = version;
    }
    get(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.GET, route, callback, this._version));
    }
    head(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.HEAD, route, callback, this._version));
    }
    post(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.POST, route, callback, this._version));
    }
    put(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.PUT, route, callback, this._version));
    }
    del(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.DELETE, route, callback, this._version));
    }
    opts(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.OPTIONS, route, callback, this._version));
    }
    patch(route, callback) {
        this._routers.push(new RouterConfigItem(HttpVerb.PATCH, route, callback, this._version));
    }
    apply(serverRouterConfig) {
        this.onConfig();
        this._routers.forEach((router) => {
            switch (router.verb) {
                case HttpVerb.GET:
                    serverRouterConfig.addGetRoute(router);
                    break;
                case HttpVerb.HEAD:
                    serverRouterConfig.addHeadRoute(router);
                    break;
                case HttpVerb.POST:
                    serverRouterConfig.addPostRoute(router);
                    break;
                case HttpVerb.PUT:
                    serverRouterConfig.addPutRoute(router);
                    break;
                case HttpVerb.DELETE:
                    serverRouterConfig.addDeleteRoute(router);
                    break;
                case HttpVerb.OPTIONS:
                    serverRouterConfig.addOptionsRoute(router);
                    break;
                case HttpVerb.PATCH:
                    serverRouterConfig.addPatchRoute(router);
                    break;
            }
        });
    }
}
exports.RouterConfig = RouterConfig;
var HttpVerb;
(function (HttpVerb) {
    HttpVerb[HttpVerb["GET"] = 0] = "GET";
    HttpVerb[HttpVerb["HEAD"] = 1] = "HEAD";
    HttpVerb[HttpVerb["POST"] = 2] = "POST";
    HttpVerb[HttpVerb["PUT"] = 3] = "PUT";
    HttpVerb[HttpVerb["DELETE"] = 4] = "DELETE";
    HttpVerb[HttpVerb["OPTIONS"] = 5] = "OPTIONS";
    HttpVerb[HttpVerb["PATCH"] = 6] = "PATCH";
})(HttpVerb = exports.HttpVerb || (exports.HttpVerb = {}));
class RouterConfigItem {
    constructor(verb, route, callback, version) {
        this._verb = verb;
        this._route = route;
        this._callback = callback;
        this._version = version;
    }
    get verb() {
        return this._verb;
    }
    get version() {
        return this._version;
    }
    get route() {
        return this._route;
    }
    get callback() {
        return this._callback;
    }
}
exports.RouterConfigItem = RouterConfigItem;
//# sourceMappingURL=BaseRouter.js.map