"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const restify = require("restify");
class ServerRouterConfig {
    constructor() {
        this._get = [];
        this._head = [];
        this._post = [];
        this._put = [];
        this._delete = [];
        this._options = [];
        this._patch = [];
    }
    addGetRoute(config) {
        this._get.push(config);
    }
    addHeadRoute(config) {
        this._head.push(config);
    }
    addPostRoute(config) {
        this._post.push(config);
    }
    addPutRoute(config) {
        this._put.push(config);
    }
    addDeleteRoute(config) {
        this._delete.push(config);
    }
    addOptionsRoute(config) {
        this._options.push(config);
    }
    addPatchRoute(config) {
        this._patch.push(config);
    }
    _mergeRoutes(prev, current) {
        const found = prev.find((el) => el.path === current.route);
        if (found) {
            found.handlers.push({ version: current.version, handler: current.callback });
            return prev;
        }
        else {
            return [...prev, { path: current.route, handlers: [{ version: current.version, handler: current.callback }] }];
        }
    }
    apply(server) {
        this._get.reduce(this._mergeRoutes, [])
            .forEach((route) => server.get(route.path, restify.plugins.conditionalHandler(route.handlers)));
        this._head.reduce(this._mergeRoutes, [])
            .forEach((route) => server.head(route.path, restify.plugins.conditionalHandler(route.handlers)));
        this._post.reduce(this._mergeRoutes, [])
            .forEach((route) => server.post(route.path, restify.plugins.conditionalHandler(route.handlers)));
        this._put.reduce(this._mergeRoutes, [])
            .forEach((route) => server.put(route.path, restify.plugins.conditionalHandler(route.handlers)));
        this._delete.reduce(this._mergeRoutes, [])
            .forEach((route) => server.del(route.path, restify.plugins.conditionalHandler(route.handlers)));
        this._options.reduce(this._mergeRoutes, [])
            .forEach((route) => server.opts(route.path, restify.plugins.conditionalHandler(route.handlers)));
        this._patch.reduce(this._mergeRoutes, [])
            .forEach((route) => server.patch(route.path, restify.plugins.conditionalHandler(route.handlers)));
    }
}
exports.ServerRouterConfig = ServerRouterConfig;
//# sourceMappingURL=ServerRouterConfig.js.map