"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const fs = require("fs-extra");
const config_1 = require("../config");
exports.overrideDir = (from, to, versionNumber) => {
    return fs.remove(`${config_1.default.srcPath}${to}`)
        .then(() => fs.copy(`${config_1.default.srcPath}${from}`, `${config_1.default.srcPath}${to}`))
        .then(() => {
        const version = fs.readJsonSync(`${config_1.default.srcPath}${to}/${config_1.default.versionFile}`);
        version.name = to;
        version.value = to;
        if (!!versionNumber)
            version.number = versionNumber;
        fs.writeJsonSync(`${config_1.default.srcPath}${to}/${config_1.default.versionFile}`, version);
        console.log("Done!");
    })
        .catch((err) => {
        throw err;
    });
};
exports.default = (versions, from, to) => {
    inquirer.prompt([
        {
            type: "list",
            name: "from",
            message: "Which version do you want to promote?",
            choices: versions
        }
    ])
        .then(function (answer) {
        from = answer.from;
        versions.splice(versions.findIndex(i => i.value === from), 1);
        if (versions.length < 1) {
            throw new Error(`Can't promote a version because you just have "${from}" version, try creating a new version`);
        }
        return inquirer.prompt([
            {
                type: "list",
                name: "to",
                message: "Promote to ...",
                choices: () => {
                    return versions;
                }
            }
        ]);
    })
        .then(function (answer) {
        to = answer.to;
        const exists = fs.pathExistsSync(`${config_1.default.srcPath}${from}`);
        if (exists) {
            return inquirer.prompt([
                {
                    type: "confirm",
                    name: "confirm",
                    message: `"${to}" directory will be overriden by the contents of "${from}". Continue? `,
                }
            ]);
        }
        else {
            throw new Error(`"${from}" directory does not exists.`);
        }
    })
        .then(({ confirm }) => {
        if (confirm) {
            return exports.overrideDir(from, to, false);
        }
        else {
            console.log("Cancelled.");
        }
    })
        .catch((err) => {
        console.log("Error: ", err.message);
    });
};
//# sourceMappingURL=cloneOperation.js.map