"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const fs = require("fs-extra");
const config_1 = require("../config");
const versionList_1 = require("./versionList");
const cloneOperation_1 = require("./cloneOperation");
exports.default = () => {
    inquirer.prompt([
        {
            type: "list",
            name: "operation",
            message: "Create a version from scratch or from a previous version",
            choices: ["scratch", "previous"]
        }
    ])
        .then((option) => {
        switch (option.operation) {
            case "scratch":
                fromScratch();
                break;
            case "previous":
                fromPrevious();
                break;
        }
    });
};
const fromScratch = () => {
    let version = {
        name: "",
        value: "",
        number: ""
    };
    inquirer.prompt([
        {
            type: "input",
            name: "versionName",
            message: "Please insert the version name Ex: current",
            validate: (input) => {
                if (!!input)
                    return true;
                return "You need to provide a version name";
            }
        }
    ])
        .then((value) => {
        version.name = value.versionName;
        version.value = value.versionName;
        inquirer.prompt([
            {
                type: "input",
                name: "versionNumber",
                message: "Please insert the version number Ex: 0.0.1",
                validate: (input) => {
                    if (!!input)
                        return true;
                    return "You need to provide a version number";
                }
            }
        ])
            .then((value) => {
            version.number = value.versionNumber;
            fs.copy(`${config_1.default.scratchPath}`, `${config_1.default.srcPath}${version.name}`).then(() => {
                fs.writeJsonSync(`${config_1.default.srcPath}${version.name}/${config_1.default.versionFile}`, version);
                console.info("Done!");
            });
        });
    });
};
const fromPrevious = () => {
    versionList_1.default().then((versions) => {
        let from = "";
        let to = "";
        let versionNumber = "";
        if (versions.length < 1) {
            throw new Error(`Can't create a new version from a previous version because is zero!, try creating a new version from scratch`);
        }
        inquirer.prompt([
            {
                type: "list",
                name: "from",
                message: "Create new version from:",
                choices: () => {
                    return versions;
                }
            }
        ])
            .then(function (answer) {
            from = answer.from;
            return inquirer.prompt([
                {
                    type: "input",
                    name: "versionName",
                    message: "Please insert the version name Ex: current", validate: (input) => {
                        if (!!input)
                            return true;
                        return "You need to provide a version name";
                    }
                }
            ]);
        })
            .then(function (answer) {
            to = answer.versionName;
            return inquirer.prompt([
                {
                    type: "input",
                    name: "versionNumber",
                    message: "Please insert the version number Ex: 0.0.1",
                    validate: (input) => {
                        if (!!input)
                            return true;
                        return "You need to provide a version number";
                    }
                }
            ]);
        })
            .then((value) => {
            const exists = fs.pathExistsSync(`${config_1.default.srcPath}${from}`);
            versionNumber = value.versionNumber;
            if (exists) {
                return inquirer.prompt([
                    {
                        type: "confirm",
                        name: "confirm",
                        message: `You will create a new version from "${from}" with the name "${to}" and version "${versionNumber}". Continue? `,
                    }
                ]);
            }
            else {
                throw new Error(`"${from}" directory does not exists.`);
            }
        })
            .then(({ confirm }) => {
            if (confirm) {
                return cloneOperation_1.overrideDir(from, to, versionNumber);
            }
            else {
                console.log("Cancelled.");
            }
        })
            .catch((err) => {
            throw new Error(`Error gathering versions: ${err.message}`);
        });
    }).catch((err) => {
        throw new Error(`Error gathering versions: ${err.message}`);
    });
};
//# sourceMappingURL=newOperation.js.map